# itkwasm-htj2k

[![PyPI version](https://badge.fury.io/py/itkwasm-htj2k.svg)](https://badge.fury.io/py/itkwasm-htj2k)

Wasm-SIMD accelerated decoding and encoding High-throughput JPEG2000 (HTJ2K) images.

[🕮 **Documentation** 📚](https://py.docs.htj2k.wasm.itk.eth.limo/)

## Installation

```sh
pip install itkwasm-htj2k
```
